if [ -z ${CONDA_BUILD+x} ]; then
    source /opt/concourse/worker/volumes/live/549ff2cc-c2f1-429f-5149-168a1908c871/volume/pymongo_1606344845138/work/build_env_setup.sh
fi
python setup.py install --single-version-externally-managed --record=record.txt